@@ -7,7 +7,7 @@ use File::Spec;
 use File::Find;
 use File::Spec::Functions qw(catdir catfile rel2abs);
 use File::Temp;
-use ExtUtils::CBuilder;
+use Capture::Tiny;
 
 =head1 NAME
 
@@ -15,11 +15,11 @@ Alien::SDL - building, finding and using SDL binaries
 
 =head1 VERSION
 
-Version 1.4.01
+Version 1.418_1
 
 =cut
 
-our $VERSION = '1.4.01';
+our $VERSION = '1.418_1';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -213,13 +213,20 @@ sub get_header_version {
 ### check presence of header(s) specified as params
 sub check_header {
   my ($package, @header) = @_;
-  print STDERR "[$package] Testing header(s): " . join(', ', @header) . "\n";
+  print STDERR "[$package] Testing header(s): " . join(', ', @header);
+
+  require ExtUtils::CBuilder; # PAR packer workaround
+  
   my $cb = ExtUtils::CBuilder->new(quiet => 1);
   my ($fs, $src) = File::Temp->tempfile('XXXXaa', SUFFIX => '.c', UNLINK => 1);
   my $inc = '';
-  $inc .= "#include <$_>\n" for @header;  
+  my $i = 0;
+  foreach (@header) {
+    @header = (splice(@header, 0, $i) , 'stdio.h', splice(@header, $i)) if $_ eq 'jpeglib.h';
+    $i++;
+  }
+  $inc .= "#include <$_>\n" for @header;
   syswrite($fs, <<MARKER); # write test source code
-#include <stdio.h>
 #if defined(_WIN32) && !defined(__CYGWIN__)
 /* GL/gl.h on Win32 requires windows.h being included before */
 #include <windows.h>
@@ -229,16 +236,22 @@ int demofunc(void) { return 0; }
 
 MARKER
   close($fs);
-  #open OLDERR, ">&STDERR";
-  #open STDERR, ">", File::Spec->devnull();  
-  my $obj = eval { $cb->compile( source => $src, extra_compiler_flags => Alien::SDL->config('cflags')); };
-  #open(STDERR, ">&OLDERR");
+  my $obj;
+  my $stdout = '';
+  my $stderr = '';
+  ($stdout, $stderr) = Capture::Tiny::capture {
+    $obj = eval { $cb->compile( source => $src, extra_compiler_flags => Alien::SDL->config('cflags')); };
+  };
   if($obj) {
+    print STDERR "\n";
     unlink $obj;
     return 1;
   }
   else {
-    print STDERR "###TEST FAILED### for: " . join(', ', @header) . "\n";
+    $stderr =~ s/[\r\n]$//;
+    $stderr =~ s/^\Q$src\E[\d\s:]*//;
+    
+    print STDERR " NOK: ($stderr)\n";
     return 0;
   }
 }
